@@ -245,6 +245,6 @@ class FlaviusHeaderExtPickup(FlaviusBase):
     """
     def __init__(self):
         super(FlaviusHeaderExtPickup, self).__init__(search_url=conf.FLAVIUS_API_HEADER_EXT_PICKUP_LIST,
-                                                     create_url=conf.FLAVIUS_API_HEADER_EXT_PICKUP_LIST,
-                                                     update_url=conf.FLAVIUS_API_HEADER_EXT_PICKUP_LIST,
+                                                     create_url=conf.FLAVIUS_API_HEADER_EXT_PICKUP_REGIST,
+                                                     update_url=conf.FLAVIUS_API_HEADER_EXT_PICKUP_REGIST,
                                                      delete_url=conf.FLAVIUS_API_HEADER_EXT_PICKUP_DELETE)
